@@ -6,10 +6,10 @@ from collections import namedtuple
 from .SparseNdarray import SparseNdarray
 from .BinaryIsometricOp import BinaryIsometricOp
 from .Cast import Cast
-from .Combine import Combine
+from .Combine import Combine, _simplify_combine
 from .Round import Round
-from .Subset import Subset
-from .Transpose import Transpose
+from .Subset import Subset, _simplify_subset
+from .Transpose import Transpose, _simplify_transpose
 from .UnaryIsometricOpSimple import UnaryIsometricOpSimple
 from .UnaryIsometricOpWithArgs import UnaryIsometricOpWithArgs
 
@@ -136,7 +136,9 @@ class DelayedArray:
         Returns:
             A ``DelayedArray`` containing the delayed transpose.
         """
-        return DelayedArray(Transpose(self._seed, perm=None))
+        tout = Transpose(self._seed, perm=None)
+        tout = _simplify_transpose(tout)
+        return DelayedArray(tout)
 
     def __repr__(self) -> str:
         """Pretty-print this ``DelayedArray``. This uses
@@ -253,12 +255,13 @@ class DelayedArray:
             seeds = []
             for x in args[0]:
                 seeds.append(_extract_seed(x))
-
             if "axis" in kwargs:
                 axis = kwargs["axis"]
             else:
                 axis = 0
-            return DelayedArray(Combine(seeds, along=axis))
+            cout = Combine(seeds, along=axis)
+            cout = _simplify_combine(cout)
+            return DelayedArray(cout)
 
         if func == numpy.transpose:
             seed = _extract_seed(args[0])
@@ -266,7 +269,9 @@ class DelayedArray:
                 axes = kwargs["axes"]
             else:
                 axes = None
-            return DelayedArray(Transpose(seed, perm=axes))
+            tout = Transpose(seed, perm=axes)
+            tout = _simplify_transpose(tout)
+            return DelayedArray(tout)
 
         if func == numpy.round:
             seed = _extract_seed(args[0])
@@ -788,27 +793,31 @@ class DelayedArray:
         return _wrap_isometric_with_args(self, other, operation="logical_and", right=False)
 
     # Subsetting.
-    def __getitem__(self, subset: Tuple[Union[slice, Sequence], ...]) -> Union["DelayedArray", ndarray]:
+    def __getitem__(self, subset) -> Union["DelayedArray", ndarray]:
         """Take a subset of this ``DelayedArray``. This follows the same logic as NumPy slicing and will generate a
         :py:class:`~delayedarray.Subset.Subset` object when the subset operation preserves the dimensionality of the
         seed, i.e., ``args`` is defined using the :py:meth:`~numpy.ix_` function.
 
         Args:
             subset:
-                A :py:class:`tuple` of length equal to the dimensionality of
-                this ``DelayedArray``.  We attempt to support most types of
-                NumPy slicing; however, only subsets that preserve
-                dimensionality will generate a delayed subset operation.
+                A :py:class:`tuple` of length equal to the dimensionality of this ``DelayedArray``, or a single integer specifying an index on the first dimension.
+                We attempt to support most types of NumPy slicing; however, only subsets that preserve dimensionality will generate a delayed subset operation.
 
         Returns:
-            If the dimensionality is preserved by ``subset``, a
-            ``DelayedArray`` containing a delayed subset operation is returned.
-            Otherwise, a :py:class:`~numpy.ndarray` is returned containing the
-            realized subset.
+            If the dimensionality is preserved by ``subset``, a ``DelayedArray`` containing a delayed subset operation is returned.
+            Otherwise, a :py:class:`~numpy.ndarray` is returned containing the realized subset.
         """
+        if not isinstance(subset, Tuple):
+            replacement = [slice(None)] * len(self.shape)
+            replacement[0] = subset
+            subset = (*replacement,)
+
         cleaned = _getitem_subset_preserves_dimensions(self.shape, subset)
         if cleaned is not None:
-            return DelayedArray(Subset(self._seed, cleaned))
+            sout = Subset(self._seed, cleaned)
+            sout = _simplify_subset(sout)
+            return DelayedArray(sout)
+
         return _getitem_subset_discards_dimensions(self._seed, subset, extract_dense_array)
 
 
